package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.DeviceLedger;

import java.util.List;

/**
 * 设备台账Service接口
 *
 * @author ruoyi
 * @date 2024-09-10
 */
public interface IDeviceLedgerService {
    /**
     * 查询设备台账
     *
     * @param id 设备台账主键
     * @return 设备台账
     */
    DeviceLedger selectDeviceLedgerById(Long id);

    /**
     * 查询设备台账列表
     *
     * @param deviceLedger 设备台账
     * @return 设备台账集合
     */
    List<DeviceLedger> selectDeviceLedgerList(DeviceLedger deviceLedger);

    /**
     * 新增设备台账
     *
     * @param deviceLedger 设备台账
     * @return 结果
     */
    int insertDeviceLedger(DeviceLedger deviceLedger);

    /**
     * 修改设备台账
     *
     * @param deviceLedger 设备台账
     * @return 结果
     */
    int updateDeviceLedger(DeviceLedger deviceLedger);

    /**
     * 批量删除设备台账
     *
     * @param ids 需要删除的设备台账主键集合
     * @return 结果
     */
    int deleteDeviceLedgerByIds(Long[] ids);

    /**
     * 删除设备台账信息
     *
     * @param id 设备台账主键
     * @return 结果
     */
    int deleteDeviceLedgerById(Long id);
}
